@@ -94,12 +94,41 @@ scale.dotprops<-function(x,center=TRUE,scale=TRUE){
 #' @rdname dotprops
 dotprops<-function(x, ...) UseMethod('dotprops')
 
+#' @S3method dotprops character
+#' @rdname dotprops
+dotprops.character <- function(x, ...) {
+  fileName <- x
+  x <- read.im3d(x)
+  l <- dotprops(x, ...)
+  attr(l,'file') <- fileName
+  fi <- file.info(fileName)
+  attr(l, 'mtime') <- fi$mtime
+  attr(l, 'size') <- fi$size
+  l
+}
+
+#' @details \code{dotprops.dotprops} will deafult to the original vale of 
+#'   \code{k} and copy over all attributes that are not set by
+#'   \code{dotprops.default}.
 #' @method dotprops dotprops
 #' @S3method dotprops dotprops
 #' @export
 #' @rdname dotprops
 dotprops.dotprops<-function(x, k=attr(x,'k'), ...) {
-  dotprops(xyzmatrix(x), k=k, ...)
+  y=dotprops(xyzmatrix(x), k=k, ...)
+  # copy over attributes, taking care not to overwrite any
+  attin=attributes(x)
+  attout=attributes(y)
+  attributes(y)<-c(attout, attin[setdiff(names(attin), names(attout))])
+  y
+}
+
+#' @S3method dotprops im3d
+#' @rdname dotprops
+dotprops.im3d <- function(x, ...) {
+  l <- ind2coord(x)
+  l <- dotprops(l, ...)
+  l
 }
 
 #' @S3method dotprops list
@@ -308,3 +337,66 @@ subset.dotprops<-function(x, subset, ...){
   if(!is.null(x$labels)) x$labels=x$labels[r]
   x
 }
+
+#' prune an object by removing points near (or far) from a target object
+#' @export
+#' @param x The object to prune. (e.g. \code{dotprops} object, see details)
+#' @param target Another object with 3d points that will determine which points 
+#'   in x are kept.
+#' @param ... Additional arguments for methods (eventually passed to 
+#'   \code{prune.default})
+#' @examples
+#' ## prune single neurons
+#' plot3d(kcs20[[1]],col='blue')
+#' plot3d(kcs20[[2]],col='red')
+#' # prune neuron 2 down to points that are close to neuron 1
+#' neuron2_close=prune(kcs20[[2]], target=kcs20[[1]], maxdist=10)
+#' plot3d(neuron2_close, col='cyan', lwd=3)
+#' neuron2_far=prune(kcs20[[2]], target=kcs20[[1]], maxdist=10, keep='far')
+#' plot3d(neuron2_far, col='magenta', lwd=3)
+#' 
+#' ## Prune a neuron with a neuronlist
+#' pruned=prune(kcs20[[11]], kcs20[setdiff(1:20, 11)], maxdist=8)
+#' plot3d(pruned, col='red', lwd=3)
+#' plot3d(kcs20[[11]], col='green', lwd=3)
+#' plot3d(kcs20,col='grey')
+prune<-function(x, target, ...) UseMethod("prune")
+
+#' @export
+#' @method prune neuron
+#' @rdname prune
+prune.neuron<-function(x, target, ...){
+  stop("prune.neuron is not yet implemented!")
+}
+
+#' @export
+#' @method prune dotprops
+#' @rdname prune
+#' @seealso \code{\link{subset.dotprops}}
+prune.dotprops<-function(x, target, ...){
+  inds=NextMethod(return.indices=TRUE)
+  subset(x, inds)
+}
+
+#' @export
+#' @method prune dotprops
+#' @rdname prune
+prune.neuronlist<-function(x, target, ...){
+  nlapply(x, prune, target=target, ...)
+}
+
+#' @export
+#' @method prune default
+#' @rdname prune
+#' @param maxdist The threshold distance for keeping points
+#' @param keep Whether to keep points in x that are near or far from the target
+#' @param return.indices Whether to return the indices that pass the test rather
+#'   than the 3d object/points (default \code{FALSE})
+prune.default<-function(x, target, maxdist, keep=c("near","far"), 
+                        return.indices=FALSE, ...){
+  keep=match.arg(keep, c("near", "far"))
+  xyzx=xyzmatrix(x)
+  nn_dists=drop(nn2(xyzmatrix(target), xyzx, k=1)$nn.dists)
+  inds=if(keep=="near") nn_dists<=maxdist else nn_dists>maxdist
+  if(return.indices) inds else xyzx[inds, , drop=FALSE]
+}
