@@ -29,6 +29,9 @@
 #' @param vertexlabels Integer labels for graph - the edge list is specified 
 #'   using these labels.
 #' @param xyz 3D coordinates of vertices (optional, Nx3 matrix)
+#' @param weights Logical value indicating whether edge weights defined by the
+#'   3D distance between points should be added to graph (default \code{FALSE})
+#'   \emph{or} a numeric vector of weights.
 #' @param directed Whether the resultant graph should be directed (default TRUE)
 #' @param graph.attributes List of named attributes to be added to the graph
 #' @return an \code{igraph} object with additional class \code{ngraph}, having a
@@ -36,16 +39,28 @@
 #'   attribute. All vertices are included whether connected or not.
 #' @family neuron
 #' @seealso \code{\link{igraph}}
-ngraph<-function(el, vertexlabels, xyz=NULL, directed=TRUE, 
+#' @export
+ngraph<-function(el, vertexlabels, xyz=NULL, directed=TRUE, weights=FALSE,
                  graph.attributes=NULL){
   if(any(duplicated(vertexlabels))) stop("Vertex labels must be unique!")
   # now translate edges into raw vertex_ids
   rawel=match(t(el), vertexlabels)
+  if(isTRUE(weights) && !is.null(xyz)){
+    # rawel is no longer a matrix
+    rawel.mat=matrix(rawel, nrow=2)
+    starts=rawel.mat[1,]
+    stops=rawel.mat[2,]
+    # nb drop = FALSE to ensure that we always have a matrix
+    vecs=xyz[stops, , drop=FALSE] - xyz[starts, , drop=FALSE]
+    weights=sqrt(rowSums(vecs*vecs))
+  }
   g=igraph::graph(rawel, n=length(vertexlabels), directed=directed)
   igraph::V(g)$label=vertexlabels
+  if(is.numeric(weights))
+    igraph::E(g)$weight=weights
   if(!is.null(xyz)) xyzmatrix(g)<-xyz
   for(n in names(graph.attributes)){
-    g=igraph::set.graph.attribute(g,name=n,value=graph.attributes[[g]])
+    g=igraph::set.graph.attribute(g,name=n,value=graph.attributes[[n]])
   }
   class(g)=c("ngraph",class(g))
   g
@@ -91,7 +106,7 @@ as.ngraph.igraph<-function(x, directed=TRUE, root, mode=c('out','in'), ...){
     if(is.directed(x)==directed) return(x)
   
   if(is.directed(x) && !directed) x=as.undirected(x, ...)
-  else if(directed) x=as.directed.usingroot(x, root, mode=mode, ...)
+  else if(!is.directed(x) && directed) x=as.directed.usingroot(x, root, mode=mode, ...)
   
   if(!inherits(x,'ngraph')){
     class(x)=c("ngraph",class(x))
@@ -124,4 +139,32 @@ as.directed.usingroot<-function(g, root, mode=c('out','in')){
   dg=igraph::delete.edges(dg,edges_to_flip)
   dg=igraph::add.edges(dg,t(el[edges_to_flip,2:1]))
   dg
-}
\ No newline at end of file
+}
+
+
+#' Compute the longest path (aka spine or backbone) of a neuron
+#' 
+#' @param n the neuron to consider.
+#' @param SpatialWeights logical indicating whether spatial distances (default) 
+#'   should be used to weight segments instead of weighting each edge equally.
+#' @param LengthOnly logical indicating whether only the length of the longest 
+#'   path should be returned (when \code{TRUE}) or whether a neuron pruned down 
+#'   to the the sequence of vertices along the path should be returned 
+#'   (\code{FALSE}, the default).
+#' @return Either a neuron object corresponding to the longest path \emph{or}
+#'   the length of the longest path when \code{LengthOnly=TRUE}).
+#' @seealso \code{\link[igraph]{diameter}}
+#' @export
+#' @examples
+#' plot3d(Cell07PNs[[1]])
+#' plot3d(spine(Cell07PNs[[1]]), lwd=4, col='black')
+spine <- function(n, SpatialWeights=TRUE, LengthOnly=FALSE) {
+  ng <- as.ngraph(n, weights=SpatialWeights)
+  if(LengthOnly) {
+    diameter(ng, directed=FALSE)
+  } else {
+    longestpath=get.diameter(ng, directed=FALSE)
+    spineGraph <- delete.vertices(ng, setdiff(V(ng), longestpath))
+    as.neuron(as.ngraph(spineGraph), vertexData=n$d[V(spineGraph)$label, ])
+  }
+}
